@@ -14,8 +14,8 @@
 # limitations under the License.
 #
 import pickle
-from abc import ABC, abstractmethod
-from typing import List, Dict
+from abc import abstractmethod
+from typing import List, Dict, Union
 
 import pandas as pd
 import mlflow
@@ -24,9 +24,25 @@ from mlflow.exceptions import MlflowException
 from mlflow.protos.databricks_pb2 import INVALID_PARAMETER_VALUE
 
 from databricks.automl_runtime.forecast import OFFSET_ALIAS_MAP
+from databricks.automl_runtime.forecast.model import ForecastModel, mlflow_forecast_log_model
 
 
-class AbstractArimaModel(ABC, mlflow.pyfunc.PythonModel):
+ARIMA_CONDA_ENV = {
+    "channels": ["conda-forge"],
+    "dependencies": [
+        {
+            "pip": [
+                f"pmdarima=={pmdarima.__version__}",
+                f"pickle=={pickle.format_version}",
+                f"pandas=={pd.__version__}",
+            ]
+        }
+    ],
+    "name": "pmdarima_env",
+}
+
+
+class AbstractArimaModel(ForecastModel):
     @abstractmethod
     def __init__(self):
         super().__init__()
@@ -43,17 +59,9 @@ class AbstractArimaModel(ABC, mlflow.pyfunc.PythonModel):
         """
         from pmdarima.arima import ARIMA  # noqa: F401
 
-    @staticmethod
-    def _validate_cols(df: pd.DataFrame, required_cols: List[str]):
-        df_cols = set(df.columns)
-        required_cols_set = set(required_cols)
-        if not required_cols_set.issubset(df_cols):
-            raise MlflowException(
-                message=(
-                    f"Input data columns '{list(df_cols)}' do not contain the required columns '{required_cols}'"
-                ),
-                error_code=INVALID_PARAMETER_VALUE,
-            )
+    @property
+    def model_env(self):
+        return ARIMA_CONDA_ENV
 
     @staticmethod
     def _get_ds_indices(start_ds: pd.Timestamp, periods: int, frequency: str) -> pd.DatetimeIndex:
@@ -105,9 +113,9 @@ class ArimaModel(AbstractArimaModel):
 
     def predict_timeseries(self, horizon: int = None) -> pd.DataFrame:
         """
-        Predict target column for given horizon and history data.
+        Predict target column for given horizon_timedelta and history data.
         :param horizon: int number of periods to forecast forward.
-        :return: A pd.DataFrame with the forecasts and confidence intervals for given horizon and history data.
+        :return: A pd.DataFrame with the forecasts and confidence intervals for given horizon_timedelta and history data.
         """
         horizon = horizon or self._horizon
         future_pd = self._forecast(horizon)
@@ -132,6 +140,7 @@ class ArimaModel(AbstractArimaModel):
 
     def _predict_impl(self, input_df: pd.DataFrame) -> pd.DataFrame:
         df = input_df.rename(columns={self._time_col: "ds"})
+        df["ds"] = pd.to_datetime(df["ds"])
         # Check if the time has correct frequency
         diff = (df["ds"] - self._start_ds) / pd.Timedelta(1, unit=self._frequency)
         if not diff.apply(float.is_integer).all():
@@ -228,7 +237,7 @@ class MultiSeriesArimaModel(AbstractArimaModel):
 
     def predict_timeseries(self, horizon: int = None) -> pd.DataFrame:
         """
-        Predict target column for given horizon and history data.
+        Predict target column for given horizon_timedelta and history data.
         :param horizon: Int number of periods to forecast forward.
         :return: A pd.DataFrame with the forecast components.
         """
@@ -280,3 +289,13 @@ class MultiSeriesArimaModel(AbstractArimaModel):
                                            self._starts[id_], self._ends[id_], self._time_col)
         df["yhat"] = arima_model_single_id.predict(None, df).to_list()
         return df
+
+
+def mlflow_arima_log_model(arima_model: Union[ArimaModel, MultiSeriesArimaModel],
+                           sample_input: pd.DataFrame = None) -> None:
+    """
+    Log the model to mlflow.
+    :param arima_model: ARIMA model wrapper
+    :param sample_input: sample input Dataframes for model inference
+    """
+    mlflow_forecast_log_model(arima_model, sample_input)
